Class: UnivapayClientSdk::CancelsApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/univapay_client_sdk/apis/cancels_api.rb

Overview

CancelsApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from UnivapayClientSdk::BaseApi

Instance Method Details

#create_cancel(store_id, charge_id, idempotency_key: nil, body: nil) ⇒ ApiResponse

Creates a new cancellation request for a charge. The charge must be in a cancellable state. Bank transfer and konbini charges that have already been paid cannot be cancelled of the store. of the charge. idempotency key to prevent double charges and duplicate operations. We recommend a randomly generated UUID (v4). payload for creating a cancel.

Parameters:

  • store_id (UUID | String)

    Required parameter: The unique identifier

  • charge_id (UUID | String)

    Required parameter: The unique identifier

  • idempotency_key (String) (defaults to: nil)

    Optional parameter: An optional

  • body (CancelCreateRequest) (defaults to: nil)

    Optional parameter: Optional metadata

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/univapay_client_sdk/apis/cancels_api.rb', line 91

def create_cancel(store_id,
                  charge_id,
                  idempotency_key: nil,
                  body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/stores/{storeId}/charges/{chargeId}/cancels',
                                 Server::DEFAULT)
               .template_param(new_parameter(store_id, key: 'storeId')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(charge_id, key: 'chargeId')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('JWT_TOKEN')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Cancel.method(:from_hash))
                .is_api_response(true)
                .local_error_template('400',
                                      'HTTP 400 Bad Request: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('401',
                                      'HTTP 401 Unauthorized: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('404',
                                      'HTTP 404 Not Found: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('403',
                                      'HTTP 403 Forbidden: {$response.body#/code}',
                                      APIException)
                .local_error_template('409',
                                      'HTTP 409 Conflict: {$response.body#/code}',
                                      APIException)
                .local_error_template('429',
                                      'HTTP 429 Rate Limited: {$response.body#/code}',
                                      APIException)
                .local_error_template('500',
                                      'HTTP 500 Server Error: {$response.body#/code}',
                                      APIException)
                .local_error_template('503',
                                      'HTTP 503 Unavailable: {$response.body#/code}',
                                      APIException)
                .local_error_template('504',
                                      'HTTP 504 Timeout: {$response.body#/code}',
                                      APIException)
                .local_error_template('default',
                                      'HTTP {$statusCode}: {$response.body#/code}',
                                      APIException))
    .execute
end

#get_cancel(store_id, charge_id, id, polling: false) ⇒ ApiResponse

Retrieves a specific cancel by ID. Supports long-polling by appending ?polling=true to wait for a status change (up to the server timeout). Requires a secret-bearing token. of the store. of the charge. resource. server holds the connection open until the cancel status changes or the polling timeout is reached.

Parameters:

  • store_id (UUID | String)

    Required parameter: The unique identifier

  • charge_id (UUID | String)

    Required parameter: The unique identifier

  • id (UUID | String)

    Required parameter: The unique identifier of the

  • polling (TrueClass | FalseClass) (defaults to: false)

    Optional parameter: If true, the

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/univapay_client_sdk/apis/cancels_api.rb', line 161

def get_cancel(store_id,
               charge_id,
               id,
               polling: false)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/stores/{storeId}/charges/{chargeId}/cancels/{id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(store_id, key: 'storeId')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(charge_id, key: 'chargeId')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .query_param(new_parameter(polling, key: 'polling'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('JWT_TOKEN')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Cancel.method(:from_hash))
                .is_api_response(true)
                .local_error_template('401',
                                      'HTTP 401 Unauthorized: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('404',
                                      'HTTP 404 Not Found: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('400',
                                      'HTTP 400 Bad Request: {$response.body#/code}',
                                      APIException)
                .local_error_template('403',
                                      'HTTP 403 Forbidden: {$response.body#/code}',
                                      APIException)
                .local_error_template('409',
                                      'HTTP 409 Conflict: {$response.body#/code}',
                                      APIException)
                .local_error_template('429',
                                      'HTTP 429 Rate Limited: {$response.body#/code}',
                                      APIException)
                .local_error_template('500',
                                      'HTTP 500 Server Error: {$response.body#/code}',
                                      APIException)
                .local_error_template('503',
                                      'HTTP 503 Unavailable: {$response.body#/code}',
                                      APIException)
                .local_error_template('504',
                                      'HTTP 504 Timeout: {$response.body#/code}',
                                      APIException)
                .local_error_template('default',
                                      'HTTP {$statusCode}: {$response.body#/code}',
                                      APIException))
    .execute
end

#list_cancels(store_id, charge_id, limit: 10, cursor: nil, cursor_direction: CursorDirectionQuery::DESC) ⇒ ApiResponse

Returns a paginated list of cancels for the specified charge. of the store. of the charge. return in one page. resource after which pagination should continue. Pagination direction relative to the supplied cursor.

Parameters:

  • store_id (UUID | String)

    Required parameter: The unique identifier

  • charge_id (UUID | String)

    Required parameter: The unique identifier

  • limit (Integer) (defaults to: 10)

    Optional parameter: Maximum number of resources to

  • cursor (UUID | String) (defaults to: nil)

    Optional parameter: Cursor pointing to the

  • cursor_direction (CursorDirectionQuery) (defaults to: CursorDirectionQuery::DESC)

    Optional parameter:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/univapay_client_sdk/apis/cancels_api.rb', line 21

def list_cancels(store_id,
                 charge_id,
                 limit: 10,
                 cursor: nil,
                 cursor_direction: CursorDirectionQuery::DESC)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/stores/{storeId}/charges/{chargeId}/cancels',
                                 Server::DEFAULT)
               .template_param(new_parameter(store_id, key: 'storeId')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(charge_id, key: 'chargeId')
                                .is_required(true)
                                .should_encode(true))
               .query_param(new_parameter(limit, key: 'limit'))
               .query_param(new_parameter(cursor, key: 'cursor'))
               .query_param(new_parameter(cursor_direction, key: 'cursor_direction'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('JWT_TOKEN')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CancelList.method(:from_hash))
                .is_api_response(true)
                .local_error_template('401',
                                      'HTTP 401 Unauthorized: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('404',
                                      'HTTP 404 Not Found: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('400',
                                      'HTTP 400 Bad Request: {$response.body#/code}',
                                      APIException)
                .local_error_template('403',
                                      'HTTP 403 Forbidden: {$response.body#/code}',
                                      APIException)
                .local_error_template('409',
                                      'HTTP 409 Conflict: {$response.body#/code}',
                                      APIException)
                .local_error_template('429',
                                      'HTTP 429 Rate Limited: {$response.body#/code}',
                                      APIException)
                .local_error_template('500',
                                      'HTTP 500 Server Error: {$response.body#/code}',
                                      APIException)
                .local_error_template('503',
                                      'HTTP 503 Unavailable: {$response.body#/code}',
                                      APIException)
                .local_error_template('504',
                                      'HTTP 504 Timeout: {$response.body#/code}',
                                      APIException)
                .local_error_template('default',
                                      'HTTP {$statusCode}: {$response.body#/code}',
                                      APIException))
    .execute
end

#update_cancel(store_id, charge_id, id, body, idempotency_key: nil) ⇒ ApiResponse

Updates metadata on an existing cancel. Requires a secret-bearing token. of the store. of the charge. resource. updating cancel metadata. idempotency key to prevent double charges and duplicate operations. We recommend a randomly generated UUID (v4).

Parameters:

  • store_id (UUID | String)

    Required parameter: The unique identifier

  • charge_id (UUID | String)

    Required parameter: The unique identifier

  • id (UUID | String)

    Required parameter: The unique identifier of the

  • body (CancelUpdateRequest)

    Required parameter: Request payload for

  • idempotency_key (String) (defaults to: nil)

    Optional parameter: An optional

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/univapay_client_sdk/apis/cancels_api.rb', line 231

def update_cancel(store_id,
                  charge_id,
                  id,
                  body,
                  idempotency_key: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PATCH,
                                 '/stores/{storeId}/charges/{chargeId}/cancels/{id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(store_id, key: 'storeId')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(charge_id, key: 'chargeId')
                                .is_required(true)
                                .should_encode(true))
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('JWT_TOKEN')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Cancel.method(:from_hash))
                .is_api_response(true)
                .local_error_template('400',
                                      'HTTP 400 Bad Request: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('401',
                                      'HTTP 401 Unauthorized: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('403',
                                      'HTTP 403 Forbidden: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('404',
                                      'HTTP 404 Not Found: {$response.body#/code}',
                                      ApiErrorException)
                .local_error_template('409',
                                      'HTTP 409 Conflict: {$response.body#/code}',
                                      APIException)
                .local_error_template('429',
                                      'HTTP 429 Rate Limited: {$response.body#/code}',
                                      APIException)
                .local_error_template('500',
                                      'HTTP 500 Server Error: {$response.body#/code}',
                                      APIException)
                .local_error_template('503',
                                      'HTTP 503 Unavailable: {$response.body#/code}',
                                      APIException)
                .local_error_template('504',
                                      'HTTP 504 Timeout: {$response.body#/code}',
                                      APIException)
                .local_error_template('default',
                                      'HTTP {$statusCode}: {$response.body#/code}',
                                      APIException))
    .execute
end