Class: UnivapayClientSdk::CardProcessorInstallmentConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UnivapayClientSdk::CardProcessorInstallmentConfig
- Defined in:
- lib/univapay_client_sdk/models/card_processor_installment_config.rb
Overview
Card-processor capabilities available for installment payments.
Instance Attribute Summary collapse
-
#fixed_cycle ⇒ TrueClass | FalseClass
Allows fixed-cycle installment payments through supported processors.
-
#revolving ⇒ TrueClass | FalseClass
Allows revolving payments through supported processors.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(revolving: SKIP, fixed_cycle: SKIP, additional_properties: nil) ⇒ CardProcessorInstallmentConfig
constructor
A new instance of CardProcessorInstallmentConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(revolving: SKIP, fixed_cycle: SKIP, additional_properties: nil) ⇒ CardProcessorInstallmentConfig
Returns a new instance of CardProcessorInstallmentConfig.
44 45 46 47 48 49 50 51 52 |
# File 'lib/univapay_client_sdk/models/card_processor_installment_config.rb', line 44 def initialize(revolving: SKIP, fixed_cycle: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @revolving = revolving unless revolving == SKIP @fixed_cycle = fixed_cycle unless fixed_cycle == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#fixed_cycle ⇒ TrueClass | FalseClass
Allows fixed-cycle installment payments through supported processors.
18 19 20 |
# File 'lib/univapay_client_sdk/models/card_processor_installment_config.rb', line 18 def fixed_cycle @fixed_cycle end |
#revolving ⇒ TrueClass | FalseClass
Allows revolving payments through supported processors.
14 15 16 |
# File 'lib/univapay_client_sdk/models/card_processor_installment_config.rb', line 14 def revolving @revolving end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/univapay_client_sdk/models/card_processor_installment_config.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. revolving = hash.key?('revolving') ? hash['revolving'] : SKIP fixed_cycle = hash.key?('fixed_cycle') ? hash['fixed_cycle'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CardProcessorInstallmentConfig.new(revolving: revolving, fixed_cycle: fixed_cycle, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/univapay_client_sdk/models/card_processor_installment_config.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['revolving'] = 'revolving' @_hash['fixed_cycle'] = 'fixed_cycle' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/univapay_client_sdk/models/card_processor_installment_config.rb', line 37 def self.nullables %w[ revolving fixed_cycle ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/univapay_client_sdk/models/card_processor_installment_config.rb', line 29 def self.optionals %w[ revolving fixed_cycle ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/univapay_client_sdk/models/card_processor_installment_config.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} revolving: #{@revolving.inspect}, fixed_cycle: #{@fixed_cycle.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/univapay_client_sdk/models/card_processor_installment_config.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} revolving: #{@revolving}, fixed_cycle: #{@fixed_cycle},"\ " additional_properties: #{@additional_properties}>" end |