Class: UnivapayClientSdk::ChargeCaptureRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/charge_capture_request.rb

Overview

Request payload for capturing an authorized charge.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount:, currency:, additional_properties: nil) ⇒ ChargeCaptureRequest

Returns a new instance of ChargeCaptureRequest.



40
41
42
43
44
45
46
47
# File 'lib/univapay_client_sdk/models/charge_capture_request.rb', line 40

def initialize(amount:, currency:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount = amount
  @currency = currency
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountInteger

The amount to capture. Must be less than or equal to the authorized amount.

Returns:

  • (Integer)


15
16
17
# File 'lib/univapay_client_sdk/models/charge_capture_request.rb', line 15

def amount
  @amount
end

#currencyString

ISO-4217 currency code. Must exactly match the currency used during authorization.

Returns:

  • (String)


20
21
22
# File 'lib/univapay_client_sdk/models/charge_capture_request.rb', line 20

def currency
  @currency
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/univapay_client_sdk/models/charge_capture_request.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = hash.key?('amount') ? hash['amount'] : nil
  currency = hash.key?('currency') ? hash['currency'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ChargeCaptureRequest.new(amount: amount,
                           currency: currency,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/univapay_client_sdk/models/charge_capture_request.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'amount'
  @_hash['currency'] = 'currency'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/univapay_client_sdk/models/charge_capture_request.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/univapay_client_sdk/models/charge_capture_request.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/univapay_client_sdk/models/charge_capture_request.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, currency: #{@currency.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/univapay_client_sdk/models/charge_capture_request.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, currency: #{@currency}, additional_properties:"\
  " #{@additional_properties}>"
end