Class: UnivapayClientSdk::ChargeCreateRequestThreeDs
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UnivapayClientSdk::ChargeCreateRequestThreeDs
- Defined in:
- lib/univapay_client_sdk/models/charge_create_request_three_ds.rb
Overview
Charge Create Request Three Ds schema.
Instance Attribute Summary collapse
-
#mode ⇒ ChargeCreateRequestThreeDsMode
3D-Secure authentication type.
-
#redirect_endpoint ⇒ String
URL to redirect the customer to after 3DS authentication.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(redirect_endpoint: SKIP, mode: ChargeCreateRequestThreeDsMode::NORMAL, additional_properties: nil) ⇒ ChargeCreateRequestThreeDs
constructor
A new instance of ChargeCreateRequestThreeDs.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(redirect_endpoint: SKIP, mode: ChargeCreateRequestThreeDsMode::NORMAL, additional_properties: nil) ⇒ ChargeCreateRequestThreeDs
Returns a new instance of ChargeCreateRequestThreeDs.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/univapay_client_sdk/models/charge_create_request_three_ds.rb', line 41 def initialize(redirect_endpoint: SKIP, mode: ChargeCreateRequestThreeDsMode::NORMAL, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @redirect_endpoint = redirect_endpoint unless redirect_endpoint == SKIP @mode = mode unless mode == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mode ⇒ ChargeCreateRequestThreeDsMode
3D-Secure authentication type. App Token Secret is required to use 'skip'.
18 19 20 |
# File 'lib/univapay_client_sdk/models/charge_create_request_three_ds.rb', line 18 def mode @mode end |
#redirect_endpoint ⇒ String
URL to redirect the customer to after 3DS authentication.
14 15 16 |
# File 'lib/univapay_client_sdk/models/charge_create_request_three_ds.rb', line 14 def redirect_endpoint @redirect_endpoint end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/univapay_client_sdk/models/charge_create_request_three_ds.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. redirect_endpoint = hash.key?('redirect_endpoint') ? hash['redirect_endpoint'] : SKIP mode = hash['mode'] ||= ChargeCreateRequestThreeDsMode::NORMAL # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ChargeCreateRequestThreeDs.new(redirect_endpoint: redirect_endpoint, mode: mode, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/univapay_client_sdk/models/charge_create_request_three_ds.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['redirect_endpoint'] = 'redirect_endpoint' @_hash['mode'] = 'mode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/univapay_client_sdk/models/charge_create_request_three_ds.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/univapay_client_sdk/models/charge_create_request_three_ds.rb', line 29 def self.optionals %w[ redirect_endpoint mode ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/univapay_client_sdk/models/charge_create_request_three_ds.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} redirect_endpoint: #{@redirect_endpoint.inspect}, mode: #{@mode.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/univapay_client_sdk/models/charge_create_request_three_ds.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} redirect_endpoint: #{@redirect_endpoint}, mode: #{@mode},"\ " additional_properties: #{@additional_properties}>" end |