Class: UnivapayClientSdk::ChargeList

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/charge_list.rb

Overview

Paginated list of charges.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(items: SKIP, has_more: SKIP, total_hits: SKIP, additional_properties: nil) ⇒ ChargeList

Returns a new instance of ChargeList.



47
48
49
50
51
52
53
54
55
56
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 47

def initialize(items: SKIP, has_more: SKIP, total_hits: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @items = items unless items == SKIP
  @has_more = has_more unless has_more == SKIP
  @total_hits = total_hits unless total_hits == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#has_moreTrueClass | FalseClass

Whether more results are available.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 18

def has_more
  @has_more
end

#itemsArray[Charge]

List of resources.

Returns:



14
15
16
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 14

def items
  @items
end

#total_hitsInteger

Total number of matching resources.

Returns:

  • (Integer)


22
23
24
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 22

def total_hits
  @total_hits
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  items = nil
  unless hash['items'].nil?
    items = []
    hash['items'].each do |structure|
      items << (Charge.from_hash(structure) if structure)
    end
  end

  items = SKIP unless hash.key?('items')
  has_more = hash.key?('has_more') ? hash['has_more'] : SKIP
  total_hits = hash.key?('total_hits') ? hash['total_hits'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ChargeList.new(items: items,
                 has_more: has_more,
                 total_hits: total_hits,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['items'] = 'items'
  @_hash['has_more'] = 'has_more'
  @_hash['total_hits'] = 'total_hits'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 34

def self.optionals
  %w[
    items
    has_more
    total_hits
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} items: #{@items.inspect}, has_more: #{@has_more.inspect}, total_hits:"\
  " #{@total_hits.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/univapay_client_sdk/models/charge_list.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} items: #{@items}, has_more: #{@has_more}, total_hits: #{@total_hits},"\
  " additional_properties: #{@additional_properties}>"
end