Class: UnivapayClientSdk::CustomsDeclarationWebhookCallbackExtension

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/customs_declaration_webhook_callback_extension.rb

Overview

Customs-declaration-specific webhook payload extension.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(data: SKIP, additional_properties: nil) ⇒ CustomsDeclarationWebhookCallbackExtension

Returns a new instance of CustomsDeclarationWebhookCallbackExtension.



37
38
39
40
41
42
43
# File 'lib/univapay_client_sdk/models/customs_declaration_webhook_callback_extension.rb', line 37

def initialize(data: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @data = data unless data == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#dataCustomsDeclarationWebhookData

Customs declaration payload delivered in customs_declaration_finished webhooks. Platform-level deliveries may include platform_id and updated_on.



16
17
18
# File 'lib/univapay_client_sdk/models/customs_declaration_webhook_callback_extension.rb', line 16

def data
  @data
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/univapay_client_sdk/models/customs_declaration_webhook_callback_extension.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  data = CustomsDeclarationWebhookData.from_hash(hash['data']) if hash['data']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CustomsDeclarationWebhookCallbackExtension.new(data: data,
                                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/univapay_client_sdk/models/customs_declaration_webhook_callback_extension.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['data'] = 'data'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/univapay_client_sdk/models/customs_declaration_webhook_callback_extension.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/univapay_client_sdk/models/customs_declaration_webhook_callback_extension.rb', line 26

def self.optionals
  %w[
    data
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
# File 'lib/univapay_client_sdk/models/customs_declaration_webhook_callback_extension.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} data: #{@data.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
# File 'lib/univapay_client_sdk/models/customs_declaration_webhook_callback_extension.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} data: #{@data}, additional_properties: #{@additional_properties}>"
end