Class: UnivapayClientSdk::IssuerTokenPayload

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/issuer_token_payload.rb

Overview

A dictionary containing necessary key-value pairs for sending the request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_data: SKIP, s_spcd: SKIP, s_cptok: SKIP, s_terkn: SKIP, additional_properties: nil) ⇒ IssuerTokenPayload

Returns a new instance of IssuerTokenPayload.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 53

def initialize(request_data: SKIP, s_spcd: SKIP, s_cptok: SKIP,
               s_terkn: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_data = request_data unless request_data == SKIP
  @s_spcd = s_spcd unless s_spcd == SKIP
  @s_cptok = s_cptok unless s_cptok == SKIP
  @s_terkn = s_terkn unless s_terkn == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_dataString

Generic payload key used by most payment providers.

Returns:

  • (String)


14
15
16
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 14

def request_data
  @request_data
end

#s_cptokString

d-barai coupon token.

Returns:

  • (String)


22
23
24
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 22

def s_cptok
  @s_cptok
end

#s_spcdString

d-barai payment service code.

Returns:

  • (String)


18
19
20
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 18

def s_spcd
  @s_spcd
end

#s_terknString

d-barai terminal key.

Returns:

  • (String)


26
27
28
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 26

def s_terkn
  @s_terkn
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_data = hash.key?('request_data') ? hash['request_data'] : SKIP
  s_spcd = hash.key?('sSpcd') ? hash['sSpcd'] : SKIP
  s_cptok = hash.key?('sCptok') ? hash['sCptok'] : SKIP
  s_terkn = hash.key?('sTerkn') ? hash['sTerkn'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IssuerTokenPayload.new(request_data: request_data,
                         s_spcd: s_spcd,
                         s_cptok: s_cptok,
                         s_terkn: s_terkn,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_data'] = 'request_data'
  @_hash['s_spcd'] = 'sSpcd'
  @_hash['s_cptok'] = 'sCptok'
  @_hash['s_terkn'] = 'sTerkn'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 39

def self.optionals
  %w[
    request_data
    s_spcd
    s_cptok
    s_terkn
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_data: #{@request_data.inspect}, s_spcd: #{@s_spcd.inspect},"\
  " s_cptok: #{@s_cptok.inspect}, s_terkn: #{@s_terkn.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/univapay_client_sdk/models/issuer_token_payload.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_data: #{@request_data}, s_spcd: #{@s_spcd}, s_cptok: #{@s_cptok},"\
  " s_terkn: #{@s_terkn}, additional_properties: #{@additional_properties}>"
end