Class: UnivapayClientSdk::MerchantWebhookCheckoutConfiguration

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb

Overview

Checkout field collection settings.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ec_email: SKIP, ec_products: SKIP, additional_properties: nil) ⇒ MerchantWebhookCheckoutConfiguration

Returns a new instance of MerchantWebhookCheckoutConfiguration.



41
42
43
44
45
46
47
48
49
# File 'lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb', line 41

def initialize(ec_email: SKIP, ec_products: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @ec_email = ec_email unless ec_email == SKIP
  @ec_products = ec_products unless ec_products == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#ec_emailMerchantWebhookCheckoutToggle

Checkout feature toggle.



14
15
16
# File 'lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb', line 14

def ec_email
  @ec_email
end

#ec_productsMerchantWebhookCheckoutToggle

Checkout feature toggle.



18
19
20
# File 'lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb', line 18

def ec_products
  @ec_products
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ec_email = MerchantWebhookCheckoutToggle.from_hash(hash['ec_email']) if hash['ec_email']
  ec_products = MerchantWebhookCheckoutToggle.from_hash(hash['ec_products']) if
    hash['ec_products']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantWebhookCheckoutConfiguration.new(ec_email: ec_email,
                                           ec_products: ec_products,
                                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ec_email'] = 'ec_email'
  @_hash['ec_products'] = 'ec_products'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb', line 29

def self.optionals
  %w[
    ec_email
    ec_products
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ec_email: #{@ec_email.inspect}, ec_products: #{@ec_products.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/univapay_client_sdk/models/merchant_webhook_checkout_configuration.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ec_email: #{@ec_email}, ec_products: #{@ec_products},"\
  " additional_properties: #{@additional_properties}>"
end