Class: UnivapayClientSdk::MerchantWebhookLimitChargeByCardConfiguration
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UnivapayClientSdk::MerchantWebhookLimitChargeByCardConfiguration
- Defined in:
- lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb
Overview
Per-card velocity limit configuration.
Instance Attribute Summary collapse
-
#duration_window ⇒ String
ISO-8601 duration for the rolling window.
-
#quantity_of_charges ⇒ Integer
Maximum number of charges allowed in the time window.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(quantity_of_charges: SKIP, duration_window: SKIP, additional_properties: nil) ⇒ MerchantWebhookLimitChargeByCardConfiguration
constructor
A new instance of MerchantWebhookLimitChargeByCardConfiguration.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(quantity_of_charges: SKIP, duration_window: SKIP, additional_properties: nil) ⇒ MerchantWebhookLimitChargeByCardConfiguration
Returns a new instance of MerchantWebhookLimitChargeByCardConfiguration.
41 42 43 44 45 46 47 48 49 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb', line 41 def initialize(quantity_of_charges: SKIP, duration_window: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @quantity_of_charges = quantity_of_charges unless quantity_of_charges == SKIP @duration_window = duration_window unless duration_window == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#duration_window ⇒ String
ISO-8601 duration for the rolling window.
18 19 20 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb', line 18 def duration_window @duration_window end |
#quantity_of_charges ⇒ Integer
Maximum number of charges allowed in the time window.
14 15 16 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb', line 14 def quantity_of_charges @quantity_of_charges end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. quantity_of_charges = hash.key?('quantity_of_charges') ? hash['quantity_of_charges'] : SKIP duration_window = hash.key?('duration_window') ? hash['duration_window'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MerchantWebhookLimitChargeByCardConfiguration.new(quantity_of_charges: quantity_of_charges, duration_window: duration_window, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['quantity_of_charges'] = 'quantity_of_charges' @_hash['duration_window'] = 'duration_window' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb', line 29 def self.optionals %w[ quantity_of_charges duration_window ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} quantity_of_charges: #{@quantity_of_charges.inspect}, duration_window:"\ " #{@duration_window.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_limit_charge_by_card_configuration.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} quantity_of_charges: #{@quantity_of_charges}, duration_window:"\ " #{@duration_window}, additional_properties: #{@additional_properties}>" end |