Class: UnivapayClientSdk::MerchantWebhookMoneyAmount

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb

Overview

Monetary amount object serialized by backend config models.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount: SKIP, currency: SKIP, additional_properties: nil) ⇒ MerchantWebhookMoneyAmount

Returns a new instance of MerchantWebhookMoneyAmount.



41
42
43
44
45
46
47
48
# File 'lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb', line 41

def initialize(amount: SKIP, currency: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount = amount unless amount == SKIP
  @currency = currency unless currency == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountInteger

Amount in minor currency units.

Returns:

  • (Integer)


14
15
16
# File 'lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb', line 14

def amount
  @amount
end

#currencyString

ISO 4217 currency code.

Returns:

  • (String)


18
19
20
# File 'lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb', line 18

def currency
  @currency
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = hash.key?('amount') ? hash['amount'] : SKIP
  currency = hash.key?('currency') ? hash['currency'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantWebhookMoneyAmount.new(amount: amount,
                                 currency: currency,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'amount'
  @_hash['currency'] = 'currency'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb', line 29

def self.optionals
  %w[
    amount
    currency
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, currency: #{@currency.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/univapay_client_sdk/models/merchant_webhook_money_amount.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, currency: #{@currency}, additional_properties:"\
  " #{@additional_properties}>"
end