Class: UnivapayClientSdk::MerchantWebhookQrScanConfiguration
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UnivapayClientSdk::MerchantWebhookQrScanConfiguration
- Defined in:
- lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb
Overview
QR scan payment settings.
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
Enables QR scan payments.
-
#forbidden_qr_scan_gateways ⇒ Array[String]
QR scan gateways disabled for the merchant.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled: SKIP, forbidden_qr_scan_gateways: SKIP, additional_properties: nil) ⇒ MerchantWebhookQrScanConfiguration
constructor
A new instance of MerchantWebhookQrScanConfiguration.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled: SKIP, forbidden_qr_scan_gateways: SKIP, additional_properties: nil) ⇒ MerchantWebhookQrScanConfiguration
Returns a new instance of MerchantWebhookQrScanConfiguration.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb', line 44 def initialize(enabled: SKIP, forbidden_qr_scan_gateways: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @enabled = enabled unless enabled == SKIP unless forbidden_qr_scan_gateways == SKIP @forbidden_qr_scan_gateways = forbidden_qr_scan_gateways end @additional_properties = additional_properties end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
Enables QR scan payments.
14 15 16 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb', line 14 def enabled @enabled end |
#forbidden_qr_scan_gateways ⇒ Array[String]
QR scan gateways disabled for the merchant.
18 19 20 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb', line 18 def forbidden_qr_scan_gateways @forbidden_qr_scan_gateways end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash.key?('enabled') ? hash['enabled'] : SKIP forbidden_qr_scan_gateways = hash.key?('forbidden_qr_scan_gateways') ? hash['forbidden_qr_scan_gateways'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MerchantWebhookQrScanConfiguration.new(enabled: enabled, forbidden_qr_scan_gateways: forbidden_qr_scan_gateways, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['forbidden_qr_scan_gateways'] = 'forbidden_qr_scan_gateways' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb', line 37 def self.nullables %w[ enabled forbidden_qr_scan_gateways ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb', line 29 def self.optionals %w[ enabled forbidden_qr_scan_gateways ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, forbidden_qr_scan_gateways:"\ " #{@forbidden_qr_scan_gateways.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_qr_scan_configuration.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, forbidden_qr_scan_gateways:"\ " #{@forbidden_qr_scan_gateways}, additional_properties: #{@additional_properties}>" end |