Class: UnivapayClientSdk::MerchantWebhookRecurringCvvConfirmationConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb

Overview

CVV confirmation rules for recurring token charges.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(enabled: SKIP, threshold: SKIP, additional_properties: nil) ⇒ MerchantWebhookRecurringCvvConfirmationConfig

Returns a new instance of MerchantWebhookRecurringCvvConfirmationConfig.



44
45
46
47
48
49
50
51
# File 'lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb', line 44

def initialize(enabled: SKIP, threshold: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @enabled = enabled unless enabled == SKIP
  @threshold = threshold unless threshold == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#enabledTrueClass | FalseClass

Enables recurring-charge CVV confirmation checks.

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb', line 14

def enabled
  @enabled
end

#thresholdArray[MerchantWebhookMoneyAmount]

Amount thresholds that trigger CVV confirmation.

Returns:



18
19
20
# File 'lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb', line 18

def threshold
  @threshold
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  enabled = hash.key?('enabled') ? hash['enabled'] : SKIP
  # Parameter is an array, so we need to iterate through it
  threshold = nil
  unless hash['threshold'].nil?
    threshold = []
    hash['threshold'].each do |structure|
      threshold << (MerchantWebhookMoneyAmount.from_hash(structure) if structure)
    end
  end

  threshold = SKIP unless hash.key?('threshold')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantWebhookRecurringCvvConfirmationConfig.new(enabled: enabled,
                                                    threshold: threshold,
                                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['enabled'] = 'enabled'
  @_hash['threshold'] = 'threshold'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
40
41
42
# File 'lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb', line 37

def self.nullables
  %w[
    enabled
    threshold
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb', line 29

def self.optionals
  %w[
    enabled
    threshold
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} enabled: #{@enabled.inspect}, threshold: #{@threshold.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/univapay_client_sdk/models/merchant_webhook_recurring_cvv_confirmation_config.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} enabled: #{@enabled}, threshold: #{@threshold}, additional_properties:"\
  " #{@additional_properties}>"
end