Class: UnivapayClientSdk::MerchantWebhookTransferScheduleConfiguration

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb

Overview

Transfer schedule configuration inherited by the merchant.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(wait_period: SKIP, period: SKIP, full_period_required: SKIP, day_of_week: SKIP, week_of_month: SKIP, day_of_month: SKIP, weekly_closing_day: SKIP, weekly_payout_day: SKIP, additional_properties: nil) ⇒ MerchantWebhookTransferScheduleConfiguration

Returns a new instance of MerchantWebhookTransferScheduleConfiguration.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 84

def initialize(wait_period: SKIP, period: SKIP, full_period_required: SKIP,
               day_of_week: SKIP, week_of_month: SKIP, day_of_month: SKIP,
               weekly_closing_day: SKIP, weekly_payout_day: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @wait_period = wait_period unless wait_period == SKIP
  @period = period unless period == SKIP
  @full_period_required = full_period_required unless full_period_required == SKIP
  @day_of_week = day_of_week unless day_of_week == SKIP
  @week_of_month = week_of_month unless week_of_month == SKIP
  @day_of_month = day_of_month unless day_of_month == SKIP
  @weekly_closing_day = weekly_closing_day unless weekly_closing_day == SKIP
  @weekly_payout_day = weekly_payout_day unless weekly_payout_day == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#day_of_monthInteger

Day of month used by monthly schedules.

Returns:

  • (Integer)


34
35
36
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 34

def day_of_month
  @day_of_month
end

#day_of_weekString

Payout day of week when using weekly schedules.

Returns:

  • (String)


26
27
28
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 26

def day_of_week
  @day_of_week
end

#full_period_requiredTrueClass | FalseClass

Whether the first transfer period must be fully completed.

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 22

def full_period_required
  @full_period_required
end

#periodString

Transfer period selected for payouts.

Returns:

  • (String)


18
19
20
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 18

def period
  @period
end

#wait_periodString

ISO-8601 period before charges become payable.

Returns:

  • (String)


14
15
16
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 14

def wait_period
  @wait_period
end

#week_of_monthInteger

Week of month used by monthly schedules.

Returns:

  • (Integer)


30
31
32
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 30

def week_of_month
  @week_of_month
end

#weekly_closing_dayString

Weekly closing day for balance aggregation.

Returns:

  • (String)


38
39
40
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 38

def weekly_closing_day
  @weekly_closing_day
end

#weekly_payout_dayString

Weekly payout day.

Returns:

  • (String)


42
43
44
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 42

def weekly_payout_day
  @weekly_payout_day
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 103

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  wait_period = hash.key?('wait_period') ? hash['wait_period'] : SKIP
  period = hash.key?('period') ? hash['period'] : SKIP
  full_period_required =
    hash.key?('full_period_required') ? hash['full_period_required'] : SKIP
  day_of_week = hash.key?('day_of_week') ? hash['day_of_week'] : SKIP
  week_of_month = hash.key?('week_of_month') ? hash['week_of_month'] : SKIP
  day_of_month = hash.key?('day_of_month') ? hash['day_of_month'] : SKIP
  weekly_closing_day =
    hash.key?('weekly_closing_day') ? hash['weekly_closing_day'] : SKIP
  weekly_payout_day =
    hash.key?('weekly_payout_day') ? hash['weekly_payout_day'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantWebhookTransferScheduleConfiguration.new(wait_period: wait_period,
                                                   period: period,
                                                   full_period_required: full_period_required,
                                                   day_of_week: day_of_week,
                                                   week_of_month: week_of_month,
                                                   day_of_month: day_of_month,
                                                   weekly_closing_day: weekly_closing_day,
                                                   weekly_payout_day: weekly_payout_day,
                                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 45

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['wait_period'] = 'wait_period'
  @_hash['period'] = 'period'
  @_hash['full_period_required'] = 'full_period_required'
  @_hash['day_of_week'] = 'day_of_week'
  @_hash['week_of_month'] = 'week_of_month'
  @_hash['day_of_month'] = 'day_of_month'
  @_hash['weekly_closing_day'] = 'weekly_closing_day'
  @_hash['weekly_payout_day'] = 'weekly_payout_day'
  @_hash
end

.nullablesObject

An array for nullable fields



73
74
75
76
77
78
79
80
81
82
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 73

def self.nullables
  %w[
    full_period_required
    day_of_week
    week_of_month
    day_of_month
    weekly_closing_day
    weekly_payout_day
  ]
end

.optionalsObject

An array for optional fields



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 59

def self.optionals
  %w[
    wait_period
    period
    full_period_required
    day_of_week
    week_of_month
    day_of_month
    weekly_closing_day
    weekly_payout_day
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



149
150
151
152
153
154
155
156
157
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 149

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} wait_period: #{@wait_period.inspect}, period: #{@period.inspect},"\
  " full_period_required: #{@full_period_required.inspect}, day_of_week:"\
  " #{@day_of_week.inspect}, week_of_month: #{@week_of_month.inspect}, day_of_month:"\
  " #{@day_of_month.inspect}, weekly_closing_day: #{@weekly_closing_day.inspect},"\
  " weekly_payout_day: #{@weekly_payout_day.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



139
140
141
142
143
144
145
146
# File 'lib/univapay_client_sdk/models/merchant_webhook_transfer_schedule_configuration.rb', line 139

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} wait_period: #{@wait_period}, period: #{@period}, full_period_required:"\
  " #{@full_period_required}, day_of_week: #{@day_of_week}, week_of_month: #{@week_of_month},"\
  " day_of_month: #{@day_of_month}, weekly_closing_day: #{@weekly_closing_day},"\
  " weekly_payout_day: #{@weekly_payout_day}, additional_properties:"\
  " #{@additional_properties}>"
end