Class: UnivapayClientSdk::RefundWebhookCallback

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/refund_webhook_callback.rb

Overview

Webhook envelope whose data payload is a Refund resource.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, created_on:, event: SKIP, data: SKIP, additional_properties: nil) ⇒ RefundWebhookCallback

Returns a new instance of RefundWebhookCallback.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 52

def initialize(id:, created_on:, event: SKIP, data: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @event = event unless event == SKIP
  @id = id
  @created_on = created_on
  @data = data unless data == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#created_onDateTime

Timestamp when the event was fired.

Returns:

  • (DateTime)


23
24
25
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 23

def created_on
  @created_on
end

#dataRefund

Represents a refund issued against a charge.

Returns:



27
28
29
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 27

def data
  @data
end

#eventRefundEvent

Event type discriminator — always refund_finished for this callback.

Returns:



15
16
17
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 15

def event
  @event
end

#idUUID | String

Unique ID of this webhook delivery.

Returns:

  • (UUID | String)


19
20
21
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 19

def id
  @id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 65

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  created_on = if hash.key?('created_on')
                 (DateTimeHelper.from_rfc3339(hash['created_on']) if hash['created_on'])
               end
  event = hash.key?('event') ? hash['event'] : SKIP
  data = Refund.from_hash(hash['data']) if hash['data']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RefundWebhookCallback.new(id: id,
                            created_on: created_on,
                            event: event,
                            data: data,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['event'] = 'event'
  @_hash['id'] = 'id'
  @_hash['created_on'] = 'created_on'
  @_hash['data'] = 'data'
  @_hash
end

.nullablesObject

An array for nullable fields



48
49
50
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 48

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
43
44
45
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 40

def self.optionals
  %w[
    event
    data
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 97

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.id,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.created_on,
                              ->(val) { val.instance_of? DateTime })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['id'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['created_on'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



125
126
127
128
129
130
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 125

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} event: #{@event.inspect}, id: #{@id.inspect}, created_on:"\
  " #{@created_on.inspect}, data: #{@data.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_custom_created_onObject



91
92
93
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 91

def to_custom_created_on
  DateTimeHelper.to_rfc3339(created_on)
end

#to_sObject

Provides a human-readable string representation of the object.



118
119
120
121
122
# File 'lib/univapay_client_sdk/models/refund_webhook_callback.rb', line 118

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} event: #{@event}, id: #{@id}, created_on: #{@created_on}, data: #{@data},"\
  " additional_properties: #{@additional_properties}>"
end