Class: UnivapayClientSdk::SubscriptionPlanSettings

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/subscription_plan_settings.rb

Overview

Configuration for limited-cycle subscriptions (Univapay side).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(plan_type: SKIP, fixed_cycles: SKIP, fixed_cycle_amount: SKIP, additional_properties: nil) ⇒ SubscriptionPlanSettings

Returns a new instance of SubscriptionPlanSettings.



47
48
49
50
51
52
53
54
55
56
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 47

def initialize(plan_type: SKIP, fixed_cycles: SKIP,
               fixed_cycle_amount: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @plan_type = plan_type unless plan_type == SKIP
  @fixed_cycles = fixed_cycles unless fixed_cycles == SKIP
  @fixed_cycle_amount = fixed_cycle_amount unless fixed_cycle_amount == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#fixed_cycle_amountInteger

Total target amount for fixed_cycle_amount plan.

Returns:

  • (Integer)


22
23
24
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 22

def fixed_cycle_amount
  @fixed_cycle_amount
end

#fixed_cyclesInteger

Number of cycles for fixed_cycles plan.

Returns:

  • (Integer)


18
19
20
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 18

def fixed_cycles
  @fixed_cycles
end

#plan_typePlanSettingsType

Plan type selector.

Returns:



14
15
16
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 14

def plan_type
  @plan_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  plan_type = hash.key?('plan_type') ? hash['plan_type'] : SKIP
  fixed_cycles = hash.key?('fixed_cycles') ? hash['fixed_cycles'] : SKIP
  fixed_cycle_amount =
    hash.key?('fixed_cycle_amount') ? hash['fixed_cycle_amount'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SubscriptionPlanSettings.new(plan_type: plan_type,
                               fixed_cycles: fixed_cycles,
                               fixed_cycle_amount: fixed_cycle_amount,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['plan_type'] = 'plan_type'
  @_hash['fixed_cycles'] = 'fixed_cycles'
  @_hash['fixed_cycle_amount'] = 'fixed_cycle_amount'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 34

def self.optionals
  %w[
    plan_type
    fixed_cycles
    fixed_cycle_amount
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
96
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} plan_type: #{@plan_type.inspect}, fixed_cycles: #{@fixed_cycles.inspect},"\
  " fixed_cycle_amount: #{@fixed_cycle_amount.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
88
# File 'lib/univapay_client_sdk/models/subscription_plan_settings.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} plan_type: #{@plan_type}, fixed_cycles: #{@fixed_cycles},"\
  " fixed_cycle_amount: #{@fixed_cycle_amount}, additional_properties:"\
  " #{@additional_properties}>"
end