Class: UnivapayClientSdk::TokenCreatePhoneNumber
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UnivapayClientSdk::TokenCreatePhoneNumber
- Defined in:
- lib/univapay_client_sdk/models/token_create_phone_number.rb
Overview
Token Create Phone Number schema.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Country code as string (e.g., '1' or '81').
-
#local_number ⇒ String
Local phone number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(country_code:, local_number:, additional_properties: nil) ⇒ TokenCreatePhoneNumber
constructor
A new instance of TokenCreatePhoneNumber.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(country_code:, local_number:, additional_properties: nil) ⇒ TokenCreatePhoneNumber
Returns a new instance of TokenCreatePhoneNumber.
38 39 40 41 42 43 44 45 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 38 def initialize(country_code:, local_number:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @country_code = country_code @local_number = local_number @additional_properties = additional_properties end |
Instance Attribute Details
#country_code ⇒ String
Country code as string (e.g., '1' or '81').
14 15 16 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 14 def country_code @country_code end |
#local_number ⇒ String
Local phone number.
18 19 20 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 18 def local_number @local_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. country_code = hash.key?('country_code') ? hash['country_code'] : nil local_number = hash.key?('local_number') ? hash['local_number'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TokenCreatePhoneNumber.new(country_code: country_code, local_number: local_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['country_code'] = 'country_code' @_hash['local_number'] = 'local_number' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 70 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.country_code, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.local_number, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['country_code'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['local_number'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} country_code: #{@country_code.inspect}, local_number:"\ " #{@local_number.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/univapay_client_sdk/models/token_create_phone_number.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} country_code: #{@country_code}, local_number: #{@local_number},"\ " additional_properties: #{@additional_properties}>" end |