Class: UnivapayClientSdk::TransactionTokenListItemUserData
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UnivapayClientSdk::TransactionTokenListItemUserData
- Defined in:
- lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb
Overview
Transaction Token List Item User Data schema.
Instance Attribute Summary collapse
-
#brand ⇒ String
Brand or network name.
-
#cardholder_name ⇒ String
Cardholder name value.
-
#email ⇒ String
Customer email address.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cardholder_name: SKIP, email: SKIP, brand: SKIP, additional_properties: nil) ⇒ TransactionTokenListItemUserData
constructor
A new instance of TransactionTokenListItemUserData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cardholder_name: SKIP, email: SKIP, brand: SKIP, additional_properties: nil) ⇒ TransactionTokenListItemUserData
Returns a new instance of TransactionTokenListItemUserData.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 47 def initialize(cardholder_name: SKIP, email: SKIP, brand: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @cardholder_name = cardholder_name unless cardholder_name == SKIP @email = email unless email == SKIP @brand = brand unless brand == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#brand ⇒ String
Brand or network name.
22 23 24 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 22 def brand @brand end |
#cardholder_name ⇒ String
Cardholder name value.
14 15 16 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 14 def cardholder_name @cardholder_name end |
#email ⇒ String
Customer email address.
18 19 20 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 18 def email @email end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cardholder_name = hash.key?('cardholder_name') ? hash['cardholder_name'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP brand = hash.key?('brand') ? hash['brand'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionTokenListItemUserData.new(cardholder_name: cardholder_name, email: email, brand: brand, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['cardholder_name'] = 'cardholder_name' @_hash['email'] = 'email' @_hash['brand'] = 'brand' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 34 def self.optionals %w[ cardholder_name email brand ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} cardholder_name: #{@cardholder_name.inspect}, email: #{@email.inspect},"\ " brand: #{@brand.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/univapay_client_sdk/models/transaction_token_list_item_user_data.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} cardholder_name: #{@cardholder_name}, email: #{@email}, brand: #{@brand},"\ " additional_properties: #{@additional_properties}>" end |