Class: UnivapayClientSdk::TransactionTokenUpdateRequestDataPhoneNumber

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb

Overview

Transaction Token Update Request Data Phone Number schema.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(country_code: SKIP, local_number: SKIP, additional_properties: nil) ⇒ TransactionTokenUpdateRequestDataPhoneNumber

Returns a new instance of TransactionTokenUpdateRequestDataPhoneNumber.



41
42
43
44
45
46
47
48
49
# File 'lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb', line 41

def initialize(country_code: SKIP, local_number: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @country_code = country_code unless country_code == SKIP
  @local_number = local_number unless local_number == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#country_codeString

Telephone country code.

Returns:

  • (String)


14
15
16
# File 'lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb', line 14

def country_code
  @country_code
end

#local_numberString

Local phone number.

Returns:

  • (String)


18
19
20
# File 'lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb', line 18

def local_number
  @local_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  country_code = hash.key?('country_code') ? hash['country_code'] : SKIP
  local_number = hash.key?('local_number') ? hash['local_number'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionTokenUpdateRequestDataPhoneNumber.new(country_code: country_code,
                                                   local_number: local_number,
                                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['country_code'] = 'country_code'
  @_hash['local_number'] = 'local_number'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb', line 29

def self.optionals
  %w[
    country_code
    local_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} country_code: #{@country_code.inspect}, local_number:"\
  " #{@local_number.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/univapay_client_sdk/models/transaction_token_update_request_data_phone_number.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} country_code: #{@country_code}, local_number: #{@local_number},"\
  " additional_properties: #{@additional_properties}>"
end