Class: UnivapayClientSdk::MerchantWebhookConvenienceConfiguration
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UnivapayClientSdk::MerchantWebhookConvenienceConfiguration
- Defined in:
- lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb
Overview
Convenience-store payment settings.
Instance Attribute Summary collapse
-
#enabled ⇒ TrueClass | FalseClass
Enables convenience-store payments.
-
#expiration ⇒ String
ISO-8601 duration before convenience payment expiry.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(enabled: SKIP, expiration: SKIP, additional_properties: nil) ⇒ MerchantWebhookConvenienceConfiguration
constructor
A new instance of MerchantWebhookConvenienceConfiguration.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(enabled: SKIP, expiration: SKIP, additional_properties: nil) ⇒ MerchantWebhookConvenienceConfiguration
Returns a new instance of MerchantWebhookConvenienceConfiguration.
44 45 46 47 48 49 50 51 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb', line 44 def initialize(enabled: SKIP, expiration: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @enabled = enabled unless enabled == SKIP @expiration = expiration unless expiration == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#enabled ⇒ TrueClass | FalseClass
Enables convenience-store payments.
14 15 16 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb', line 14 def enabled @enabled end |
#expiration ⇒ String
ISO-8601 duration before convenience payment expiry.
18 19 20 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb', line 18 def expiration @expiration end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. enabled = hash.key?('enabled') ? hash['enabled'] : SKIP expiration = hash.key?('expiration') ? hash['expiration'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MerchantWebhookConvenienceConfiguration.new(enabled: enabled, expiration: expiration, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['enabled'] = 'enabled' @_hash['expiration'] = 'expiration' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb', line 37 def self.nullables %w[ enabled expiration ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb', line 29 def self.optionals %w[ enabled expiration ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled.inspect}, expiration: #{@expiration.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/univapay_client_sdk/models/merchant_webhook_convenience_configuration.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} enabled: #{@enabled}, expiration: #{@expiration}, additional_properties:"\ " #{@additional_properties}>" end |