Class: UnivapayClientSdk::SubscriptionInstallmentPlan
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- UnivapayClientSdk::SubscriptionInstallmentPlan
- Defined in:
- lib/univapay_client_sdk/models/subscription_installment_plan.rb
Overview
Configuration for credit card company side installments.
Instance Attribute Summary collapse
-
#fixed_cycles ⇒ InstallmentFixedCycles
Required if plan_type is fixed_cycles.
-
#plan_type ⇒ InstallmentPlanType
Plan type selector.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(plan_type: SKIP, fixed_cycles: SKIP, additional_properties: nil) ⇒ SubscriptionInstallmentPlan
constructor
A new instance of SubscriptionInstallmentPlan.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(plan_type: SKIP, fixed_cycles: SKIP, additional_properties: nil) ⇒ SubscriptionInstallmentPlan
Returns a new instance of SubscriptionInstallmentPlan.
41 42 43 44 45 46 47 48 49 |
# File 'lib/univapay_client_sdk/models/subscription_installment_plan.rb', line 41 def initialize(plan_type: SKIP, fixed_cycles: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @plan_type = plan_type unless plan_type == SKIP @fixed_cycles = fixed_cycles unless fixed_cycles == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#fixed_cycles ⇒ InstallmentFixedCycles
Required if plan_type is fixed_cycles.
18 19 20 |
# File 'lib/univapay_client_sdk/models/subscription_installment_plan.rb', line 18 def fixed_cycles @fixed_cycles end |
#plan_type ⇒ InstallmentPlanType
Plan type selector.
14 15 16 |
# File 'lib/univapay_client_sdk/models/subscription_installment_plan.rb', line 14 def plan_type @plan_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/univapay_client_sdk/models/subscription_installment_plan.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. plan_type = hash.key?('plan_type') ? hash['plan_type'] : SKIP fixed_cycles = hash.key?('fixed_cycles') ? hash['fixed_cycles'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SubscriptionInstallmentPlan.new(plan_type: plan_type, fixed_cycles: fixed_cycles, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/univapay_client_sdk/models/subscription_installment_plan.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['plan_type'] = 'plan_type' @_hash['fixed_cycles'] = 'fixed_cycles' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/univapay_client_sdk/models/subscription_installment_plan.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/univapay_client_sdk/models/subscription_installment_plan.rb', line 29 def self.optionals %w[ plan_type fixed_cycles ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/univapay_client_sdk/models/subscription_installment_plan.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} plan_type: #{@plan_type.inspect}, fixed_cycles: #{@fixed_cycles.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/univapay_client_sdk/models/subscription_installment_plan.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} plan_type: #{@plan_type}, fixed_cycles: #{@fixed_cycles},"\ " additional_properties: #{@additional_properties}>" end |